@@ -10,12 +10,12 @@ use SPVM 'Examples::Prime';
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-11-23'; # DATE
 our $DIST = 'Bencher-Scenarios-SPVM'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 our $scenario = {
-    summary => 'Benchmark SPVM (sum two numbers)',
+    summary => 'Benchmark SPVM (check if number is prime)',
     modules => {
-        'SPVM' => {version => '0.0238'},
+        'SPVM' => {version => '0.9662'},
         'SPVM::Examples' => {}, # to pull dependency
     },
     participants => [
@@ -39,7 +39,7 @@ sub is_prime {
 }
 
 1;
-# ABSTRACT: Benchmark SPVM (sum two numbers)
+# ABSTRACT: Benchmark SPVM (check if number is prime)
 
 __END__
 
@@ -49,11 +49,11 @@ __END__
 
 =head1 NAME
 
-Bencher::Scenario::SPVM::Prime - Benchmark SPVM (sum two numbers)
+Bencher::Scenario::SPVM::Prime - Benchmark SPVM (check if number is prime)
 
 =head1 VERSION
 
-This document describes version 0.003 of Bencher::Scenario::SPVM::Prime (from Perl distribution Bencher-Scenarios-SPVM), released on 2022-11-23.
+This document describes version 0.004 of Bencher::Scenario::SPVM::Prime (from Perl distribution Bencher-Scenarios-SPVM), released on 2022-11-23.
 
 =head1 SYNOPSIS
 
@@ -100,21 +100,21 @@ Run on: perl: I<< v5.34.0 >>, CPU: I<< Intel(R) Core(TM) i5-7200U CPU @ 2.50GHz
 Benchmark with default options (C<< bencher -m SPVM::Prime >>):
 
  #table1#
- +-------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
- | participant | rate (/s) | time (ms) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors   | samples |
- +-------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
- | Perl        |        20 |      50   |                 0.00% |              1686.99% |   0.00018 |      20 |
- | SPVM        |        38 |      27   |                86.65% |               857.40% | 6.6e-05   |      20 |
- | Inline::C   |       360 |       2.8 |              1686.99% |                 0.00% | 1.7e-05   |      20 |
- +-------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
+ +-------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
+ | participant | rate (/s) | time (ms) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
+ +-------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
+ | Perl        |        21 |        47 |                 0.00% |              1589.46% | 5.4e-05 |      20 |
+ | SPVM        |        40 |        25 |                91.17% |               783.76% | 7.2e-05 |      21 |
+ | Inline::C   |       400 |         3 |              1589.46% |                 0.00% | 3.2e-05 |      20 |
+ +-------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
 
 Formatted as L<Benchmark.pm|Benchmark> result:
 
               Rate   Perl  SPVM  Inline::C 
-  Perl        20/s     --  -46%       -94% 
-  SPVM        38/s    85%    --       -89% 
-  Inline::C  360/s  1685%  864%         -- 
+  Perl        21/s     --  -46%       -93% 
+  SPVM        40/s    87%    --       -88% 
+  Inline::C  400/s  1466%  733%         -- 
  
  Legends:
    Inline::C: participant=Inline::C
